@@ -30,7 +30,6 @@ use sn_routing::{
     EventStream, {Prefix, XorName},
 };
 use std::{
-    collections::BTreeSet,
     fmt::{self, Display, Formatter},
     net::SocketAddr,
     path::{Path, PathBuf},
@@ -88,7 +87,6 @@ impl Node {
         let node = Self {
             role: Role::Adult(AdultRole {
                 chunks: Chunks::new(node_info.root_dir.as_path(), config.max_capacity()).await?,
-                adult_list: BTreeSet::new(),
             }),
             node_info,
             used_space: UsedSpace::new(config.max_capacity()),
