@@ -13,7 +13,7 @@ use crate::{
 };
 use itertools::Itertools;
 use log::{info, trace, warn};
-use sn_data_types::BlobAddress;
+use sn_data_types::{Blob, BlobAddress};
 use sn_messaging::{
     client::{Message, NodeCmd, NodeSystemCmd},
     Aggregation, DstLocation, MessageId,
@@ -35,16 +35,30 @@ impl AdultRole {
         remaining: BTreeSet<XorName>,
     ) -> NodeDuties {
         let keys = self.chunks.keys();
-        let mut ops = vec![];
+        let mut data_for_replication = BTreeSet::new();
         for addr in keys.iter() {
-            if let Some(operation) = self
+            if let Some(data) = self
                 .republish_and_cache(addr, &our_name, &new_adults, &lost_adults, &remaining)
                 .await
             {
-                ops.push(operation);
+                let _ = data_for_replication.insert(data);
             }
         }
-        ops
+        data_for_replication
+            .into_iter()
+            .map(|data| {
+                let data_name = *data.name();
+                NodeDuty::Send(OutgoingMsg {
+                    msg: Message::NodeCmd {
+                        cmd: NodeCmd::System(NodeSystemCmd::RepublishChunk(data)),
+                        id: MessageId::new(),
+                    },
+                    dst: DstLocation::Section(data_name),
+                    section_source: false,
+                    aggregation: Aggregation::None,
+                })
+            })
+            .collect::<Vec<_>>()
     }
 
     async fn republish_and_cache(
@@ -54,7 +68,7 @@ impl AdultRole {
         new_adults: &BTreeSet<XorName>,
         lost_adults: &BTreeSet<XorName>,
         remaining: &BTreeSet<XorName>,
-    ) -> Option<NodeDuty> {
+    ) -> Option<Blob> {
         let old_adult_list = remaining.union(lost_adults).copied().collect();
         let new_adult_list = remaining.union(new_adults).copied().collect();
         let new_holders = self.compute_holders(addr, &new_adult_list);
@@ -65,8 +79,7 @@ impl AdultRole {
         let lost_old_holder = !old_holders.is_disjoint(lost_adults);
 
         if we_are_not_holder_anymore || new_adult_is_holder || lost_old_holder {
-            let id = MessageId::new();
-            info!("Republishing chunk at {:?} with MessageId {:?}", addr, id);
+            info!("Republishing chunk at {:?}", addr);
             trace!("We are not a holder anymore? {}, New Adult is Holder? {}, Lost Adult was holder? {}", we_are_not_holder_anymore, new_adult_is_holder, lost_old_holder);
             let chunk = self.chunks.get_chunk(addr).ok()?;
             if we_are_not_holder_anymore {
@@ -75,15 +88,7 @@ impl AdultRole {
                 }
             }
             // TODO: Push to LRU cache
-            Some(NodeDuty::Send(OutgoingMsg {
-                msg: Message::NodeCmd {
-                    cmd: NodeCmd::System(NodeSystemCmd::RepublishChunk(chunk)),
-                    id,
-                },
-                dst: DstLocation::Section(*addr.name()),
-                section_source: false,
-                aggregation: Aggregation::None,
-            }))
+            Some(chunk)
         } else {
             None
         }
